# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class JobKind(str, Enum):
    """
    JobKind
    """

    """
    allowed enum values
    """
    METRICS_CALCULATION = 'metrics_calculation'
    CONNECTOR_CHECK = 'connector_check'
    LIST_DATASETS = 'list_datasets'
    SCHEMA_INSPECTION = 'schema_inspection'
    FETCH_DATA = 'fetch_data'
    ALERT_CHECK = 'alert_check'
    SCHEDULE_JOBS = 'schedule_jobs'
    CREATE_MODEL_TASK = 'create_model_task'
    CREATE_MODEL_LINK_TASK = 'create_model_link_task'
    UPDATE_MODEL_TASK_RULES = 'update_model_task_rules'
    DELETE_MODEL_TASK = 'delete_model_task'
    FETCH_MODEL_TASK = 'fetch_model_task'
    REGENERATE_TASK_VALIDATION_KEY = 'regenerate_task_validation_key'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of JobKind from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.custom_aggregation_version_spec_schema import CustomAggregationVersionSpecSchema
from typing import Optional, Set
from typing_extensions import Self

class CustomAggregationSpecSchema(BaseModel):
    """
    CustomAggregationSpecSchema
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the custom aggregation with version.")
    name: StrictStr = Field(description="Name of the custom aggregation function.")
    description: Optional[StrictStr] = None
    workspace_id: StrictStr = Field(description="Unique identifier of the custom aggregation's parent workspace.")
    versions: List[CustomAggregationVersionSpecSchema] = Field(description="List of versions of the custom aggregation configuration.")
    latest_version: StrictInt = Field(description="Max/latest version of the custom aggregation that exists. This version may or may not be included in the list of versions depending on applied filters.")
    deleted_at: Optional[datetime] = None
    is_deleted: Optional[StrictBool] = Field(default=False, description="Flag indicating if the aggregation has been soft deleted.")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "workspace_id", "versions", "latest_version", "deleted_at", "is_deleted"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in versions (list)
        _items = []
        if self.versions:
            for _item_versions in self.versions:
                if _item_versions:
                    _items.append(_item_versions.to_dict())
            _dict['versions'] = _items
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if deleted_at (nullable) is None
        # and model_fields_set contains the field
        if self.deleted_at is None and "deleted_at" in self.model_fields_set:
            _dict['deleted_at'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CustomAggregationSpecSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "workspace_id": obj.get("workspace_id"),
            "versions": [CustomAggregationVersionSpecSchema.from_dict(_item) for _item in obj["versions"]] if obj.get("versions") is not None else None,
            "latest_version": obj.get("latest_version"),
            "deleted_at": obj.get("deleted_at"),
            "is_deleted": obj.get("is_deleted") if obj.get("is_deleted") is not None else False
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.alert_rule_interval import AlertRuleInterval
from arthur_client.api_bindings.models.post_metrics_query_time_range import PostMetricsQueryTimeRange
from arthur_client.api_bindings.models.result_filter import ResultFilter
from typing import Optional, Set
from typing_extensions import Self

class PostMetricsQuery(BaseModel):
    """
    PostMetricsQuery
    """ # noqa: E501
    query: StrictStr = Field(description="Query for retrieving the metrics.")
    time_range: PostMetricsQueryTimeRange = Field(description="Time range to filter the metrics by.")
    interval: Optional[AlertRuleInterval] = None
    limit: Optional[StrictInt] = Field(default=50, description="Limit the number of metrics returned. Defaults to 50.")
    result_filter: Optional[ResultFilter] = None
    __properties: ClassVar[List[str]] = ["query", "time_range", "interval", "limit", "result_filter"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PostMetricsQuery from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of time_range
        if self.time_range:
            _dict['time_range'] = self.time_range.to_dict()
        # override the default output from pydantic by calling `to_dict()` of interval
        if self.interval:
            _dict['interval'] = self.interval.to_dict()
        # override the default output from pydantic by calling `to_dict()` of result_filter
        if self.result_filter:
            _dict['result_filter'] = self.result_filter.to_dict()
        # set to None if interval (nullable) is None
        # and model_fields_set contains the field
        if self.interval is None and "interval" in self.model_fields_set:
            _dict['interval'] = None

        # set to None if result_filter (nullable) is None
        # and model_fields_set contains the field
        if self.result_filter is None and "result_filter" in self.model_fields_set:
            _dict['result_filter'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PostMetricsQuery from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "query": obj.get("query"),
            "time_range": PostMetricsQueryTimeRange.from_dict(obj["time_range"]) if obj.get("time_range") is not None else None,
            "interval": AlertRuleInterval.from_dict(obj["interval"]) if obj.get("interval") is not None else None,
            "limit": obj.get("limit") if obj.get("limit") is not None else 50,
            "result_filter": ResultFilter.from_dict(obj["result_filter"]) if obj.get("result_filter") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.base_column_parameter_schema_allowed_column_types_inner import BaseColumnParameterSchemaAllowedColumnTypesInner
from arthur_client.api_bindings.models.scope_schema_tag import ScopeSchemaTag
from typing import Optional, Set
from typing_extensions import Self

class MetricsColumnParameterSchema(BaseModel):
    """
    MetricsColumnParameterSchema
    """ # noqa: E501
    parameter_key: StrictStr = Field(description="Name of the parameter.")
    friendly_name: StrictStr = Field(description="User facing name of the parameter.")
    description: StrictStr = Field(description="Description of the parameter.")
    tag_hints: Optional[List[ScopeSchemaTag]] = Field(default=None, description="List of tags that are applicable to this parameter. Datasets with columns that have matching tags can be inferred this way.")
    source_dataset_parameter_key: StrictStr = Field(description="Name of the parameter that provides the dataset to be used for this column.")
    allowed_column_types: Optional[List[BaseColumnParameterSchemaAllowedColumnTypesInner]] = None
    allow_any_column_type: Optional[StrictBool] = Field(default=False, description="Indicates if this metric parameter can accept any column type.")
    parameter_type: Optional[StrictStr] = 'column'
    optional: Optional[StrictBool] = Field(default=False, description="Boolean denoting if the parameter is optional.")
    __properties: ClassVar[List[str]] = ["parameter_key", "friendly_name", "description", "tag_hints", "source_dataset_parameter_key", "allowed_column_types", "allow_any_column_type", "parameter_type", "optional"]

    @field_validator('parameter_type')
    def parameter_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['column']):
            raise ValueError("must be one of enum values ('column')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetricsColumnParameterSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in allowed_column_types (list)
        _items = []
        if self.allowed_column_types:
            for _item_allowed_column_types in self.allowed_column_types:
                if _item_allowed_column_types:
                    _items.append(_item_allowed_column_types.to_dict())
            _dict['allowed_column_types'] = _items
        # set to None if allowed_column_types (nullable) is None
        # and model_fields_set contains the field
        if self.allowed_column_types is None and "allowed_column_types" in self.model_fields_set:
            _dict['allowed_column_types'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetricsColumnParameterSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "parameter_key": obj.get("parameter_key"),
            "friendly_name": obj.get("friendly_name"),
            "description": obj.get("description"),
            "tag_hints": obj.get("tag_hints"),
            "source_dataset_parameter_key": obj.get("source_dataset_parameter_key"),
            "allowed_column_types": [BaseColumnParameterSchemaAllowedColumnTypesInner.from_dict(_item) for _item in obj["allowed_column_types"]] if obj.get("allowed_column_types") is not None else None,
            "allow_any_column_type": obj.get("allow_any_column_type") if obj.get("allow_any_column_type") is not None else False,
            "parameter_type": obj.get("parameter_type") if obj.get("parameter_type") is not None else 'column',
            "optional": obj.get("optional") if obj.get("optional") is not None else False
        })
        return _obj


